@@ -171,6 +171,8 @@ func NewCommand(f client.Factory) *cobra.Command {
 			logger.Infof("setting log-level to %s", strings.ToUpper(logLevel.String()))
 
 			logger.Infof("Starting Velero server %s (%s)", buildinfo.Version, buildinfo.FormattedGitSHA())
+			logger.Infof("Konveyor Patch #1 - Bump restic repo timeout")
+			logger.Infof("Konveyor Patch #2 - Add procpps-ng package to the container")
 			if len(features.All()) > 0 {
 				logger.Infof("%d feature flags enabled %s", len(features.All()), features.All())
 			} else {
